import { ZoneGlobalDisableConfigurationsKey, ZoneGlobalEventsConfigurationsKey, ZoneGlobalSettingsConfigurationsKey, ZoneRuntimeConfigurationsKey, ZoneTestDisableConfigurationsKey, ZoneTestSettingsConfigurationsKey } from './model/configurations.types';
declare type GlobalDisableConfigurationMethods = {
    [disabledFlag in ZoneGlobalDisableConfigurationsKey]: (isDisabled?: boolean) => void;
} & {
    [symbolFlag in ZoneGlobalSettingsConfigurationsKey]: (isDisabled?: boolean) => void;
};
declare type TestDisableConfigurationMethods = {
    [disabledFlag in ZoneTestDisableConfigurationsKey]: (isDisabled?: boolean) => void;
} & {
    [symbolFlag in ZoneTestSettingsConfigurationsKey]: (isDisabled?: boolean) => void;
};
declare type ZoneGlobalEventsConfigurationsMethods = {
    [disabledFlag in ZoneGlobalEventsConfigurationsKey]: (eventNames: string[]) => void;
};
declare type RuntimeConfigurationMethods = {
    [disabledFlag in ZoneRuntimeConfigurationsKey]: (isDisabled?: boolean) => void;
};
/**
 * An object for typed zone-flags configuration.
 *
 * @Example
 *
 * create file `zone-flags.ts` parallel to your `polyfills.ts` and insert following content:
 * ```typescript
 * import { globalEvents,xhrEvent, zoneConfig} from '@rx-angular/cdk/zone-flags';
 *
 * const zoneConfig = createZoneFlagsConfigurator();
 *
 * zoneConfig.global.disable.requestAnimationFrame();
 * zoneConfig.global.disable.timers();
 * zoneConfig.events.disable.UNPATCHED_EVENTS([...globalEvents, ...xhrEvent]);
 * ```
 * In `polyfills.ts` above the zone import, import `zone-flags.ts`
 *
 * ```typescript
 * import './zone-flags';
 * // Zone JS is required by default for Angular itself.
 * import 'zone.js/dist/zone';
 * ```
 *
 */
export interface ZoneConfig {
    global: {
        disable: GlobalDisableConfigurationMethods;
    };
    test: {
        disable: TestDisableConfigurationMethods;
    };
    events: {
        disable: ZoneGlobalEventsConfigurationsMethods;
    };
    runtime: {
        disable: RuntimeConfigurationMethods;
    };
}
export declare const zoneConfig: ZoneConfig;
export {};
